@@ -1,8 +1,8 @@
 from pandas.core.dtypes.dtypes import register_extension_dtype
-from .base import NumpyExtensionArray, NumpyFloat32ExtensionDtype
+from .base import MTZFloatArray, MTZFloat32Dtype
 
 @register_extension_dtype
-class MTZRealDtype(NumpyFloat32ExtensionDtype):
+class MTZRealDtype(MTZFloat32Dtype):
     """Dtype for generic MTZ real data"""
     
     name = 'MTZReal'
@@ -12,7 +12,7 @@ class MTZRealDtype(NumpyFloat32ExtensionDtype):
     def construct_array_type(cls):
         return MTZRealArray
 
-class MTZRealArray(NumpyExtensionArray):
+class MTZRealArray(MTZFloatArray):
     """ExtensionArray for supporting MtzRealDtype"""
     _dtype = MTZRealDtype()
     pass
