@@ -1,6 +1,6 @@
 import numpy as np
 from gemmi import SpaceGroup,GroupOps
-from reciprocalspaceship.utils import apply_to_hkl, phase_shift, is_centric
+from reciprocalspaceship.utils import apply_to_hkl, phase_shift, is_centric, is_absent, generate_reciprocal_cell
 
 ccp4_hkl_asu = [
   0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,  
@@ -175,3 +175,39 @@ def hkl_to_observed(H, isym, sg, return_phase_shifts=False):
         return observed_H, phi_coeff, np.rad2deg(phi_shift)
     return observed_H
 
+def generate_reciprocal_asu(cell, spacegroup, dmin, anomalous=False):
+    """
+    Generate the Miller indices of the reflections in the reciprocal ASU.
+
+    If `anomalous=True` the Miller indices of acentric reflections will be
+    included in both the Friedel-plus and Friedel-minus halves of reciprocal
+    space. Centric Miller indices will only be included in the Friedel-plus
+    reciprocal ASU.
+
+    Parameters
+    ----------
+    cell : gemmi.UnitCell
+        A gemmi cell object.
+    spacegroup : gemmi.SpaceGroup
+        A gemmi spacegroup object.
+    dmin : float
+        Maximum resolution of the data in Å
+    anomalous : bool
+        Whether to include Friedel-minus Miller indices to represent anomalous data
+
+    Returns
+    -------
+    hasu : np.array (np.int32)
+        n by 3 array of miller indices in the reciprocal ASU.
+    """
+    p1_hkl = generate_reciprocal_cell(cell, dmin)
+    #Remove absences
+    hkl = p1_hkl[~is_absent(p1_hkl, spacegroup)]
+    #Map to ASU
+    hasu = hkl[in_asu(hkl, spacegroup)]
+    if anomalous:
+        hasu_minus = -hasu[~is_centric(hasu, spacegroup)]
+        return np.unique(np.concatenate([hasu, hasu_minus]), axis=0)
+    return np.unique(hasu, axis=0)
+
+
